<?php

namespace Assetdocs\Transferrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Transferrequest\Http\Requests\TransferrequestAdminWebRequest;
use Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface;
use Assetdocs\Transferrequest\Models\Transferrequest;

/**
 * Admin web controller class.
 */
class TransferrequestAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize transferrequest controller.
     *
     * @param type TransferrequestRepositoryInterface $transferrequest
     *
     * @return type
     */
    public function __construct(TransferrequestRepositoryInterface $transferrequest)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $transferrequest;
        parent::__construct();
    }

    /**
     * Display a list of transferrequest.
     *
     * @return Response
     */
    public function index(TransferrequestAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $transferrequests  = $this->repository
            ->pushCriteria(new \Assetdocs\Transferrequest\Repositories\Criteria\TransferrequestAdminCriteria())
                ->setPresenter('\\Assetdocs\\Transferrequest\\Repositories\\Presenter\\TransferrequestListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $transferrequests['recordsTotal']    = $transferrequests['meta']['pagination']['total'];
            $transferrequests['recordsFiltered'] = $transferrequests['meta']['pagination']['total'];
            $transferrequests['request']         = $request->all();
            return response()->json($transferrequests, 200);

        }

        $this   ->theme->prependTitle(trans('transferrequest::transferrequest.names').' :: ');
        return $this->theme->of('transferrequest::admin.transferrequest.index')->render();
    }

    /**
     * Display transferrequest.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return Response
     */
    public function show(TransferrequestAdminWebRequest $request, Transferrequest $transferrequest)
    {
        if (!$transferrequest->exists) {
            return response()->view('transferrequest::admin.transferrequest.new', compact('transferrequest'));
        }

        Form::populate($transferrequest);
        return response()->view('transferrequest::admin.transferrequest.show', compact('transferrequest'));
    }

    /**
     * Show the form for creating a new transferrequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TransferrequestAdminWebRequest $request)
    {

        $transferrequest = $this->repository->newInstance([]);

        Form::populate($transferrequest);

        return response()->view('transferrequest::admin.transferrequest.create', compact('transferrequest'));

    }

    /**
     * Create new transferrequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TransferrequestAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $transferrequest          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('transferrequest::transferrequest.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/transferrequest/transferrequest/'.$transferrequest->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show transferrequest for editing.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return Response
     */
    public function edit(TransferrequestAdminWebRequest $request, Transferrequest $transferrequest)
    {
        Form::populate($transferrequest);
        return  response()->view('transferrequest::admin.transferrequest.edit', compact('transferrequest'));
    }

    /**
     * Update the transferrequest.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return Response
     */
    public function update(TransferrequestAdminWebRequest $request, Transferrequest $transferrequest)
    {
        try {

            $attributes = $request->all();

            $transferrequest->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('transferrequest::transferrequest.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/transferrequest/transferrequest/'.$transferrequest->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/transferrequest/transferrequest/'.$transferrequest->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the transferrequest.
     *
     * @param Model   $transferrequest
     *
     * @return Response
     */
    public function destroy(TransferrequestAdminWebRequest $request, Transferrequest $transferrequest)
    {

        try {

            $t = $transferrequest->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('transferrequest::transferrequest.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/transferrequest/transferrequest/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/transferrequest/transferrequest/'.$transferrequest->getRouteKey()),
            ], 400);
        }
    }
}
